@@ -2,11 +2,12 @@ import wave
 from pyaudio import PyAudio, paInt16
 import matplotlib.pyplot as plt
 import numpy as np
+from playsound import playsound
  
  
 CHUNK = 1024 # wav文件是由若干个CHUNK组成的，CHUNK我们就理解成数据包或者数据片段。
 FORMAT = paInt16 # 表示我们使用量化位数 16位来进行录音
-CHANNELS = 1 #代表的是声道，1是单声道，2是双声道。
+CHANNELS = 2 #代表的是声道，1是单声道，2是双声道。
 RATE = 16000 # 采样率 一秒内对声音信号的采集次数，常用的有8kHz, 16kHz, 32kHz, 48kHz,
                 # 11.025kHz, 22.05kHz, 44.1kHz。
 # RECORD_SECONDS = 5 # 录制时间这里设定了5秒
@@ -130,4 +131,15 @@ def sound_draw(filename):
 	plt.subplot(212) 
 	plt.plot(time, wave_data[1], c="g")
 	plt.xlabel("time (seconds)")
-	plt.show()
\ No newline at end of file
+	plt.show()
+
+	
+def save_mp3(result ,filePath):
+	if not isinstance(result, dict):
+		with open(filePath, 'wb') as f:
+			f.write(result)
+
+
+def play_mp3(filePath):
+	playsound(filePath)
+	print('播放结束')
